@@ -21,6 +21,7 @@ class HookMetadata(t.TypedDict):
     language: str | None
     entry: str | None
     experimental: bool
+    pass_filenames: bool | None
 
 
 class ConfigMode(t.TypedDict):
@@ -32,6 +33,24 @@ class ConfigMode(t.TypedDict):
 
 HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
     "structure": [
+        {
+            "id": "validate-regex-patterns",
+            "name": "validate-regex-patterns",
+            "repo": "local",
+            "rev": "",
+            "tier": 1,
+            "time_estimate": 0.3,
+            "stages": None,
+            "args": None,
+            "files": r"\.py$",
+            "exclude": r"^\.venv/",
+            "additional_dependencies": None,
+            "types_or": None,
+            "language": "system",
+            "entry": "uv run python -m crackerjack.tools.validate_regex_patterns",
+            "experimental": False,
+            "pass_filenames": None,
+        },
         {
             "id": "trailing-whitespace",
             "name": "trailing-whitespace",
@@ -48,6 +67,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "end-of-file-fixer",
@@ -65,6 +85,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "check-yaml",
@@ -82,6 +103,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "check-toml",
@@ -99,6 +121,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "check-added-large-files",
@@ -116,6 +139,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
     ],
     "package_management": [
@@ -123,18 +147,19 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "id": "uv-lock",
             "name": None,
             "repo": "https://github.com/astral-sh/uv-pre-commit",
-            "rev": "0.8.14",
+            "rev": "0.8.15",
             "tier": 1,
             "time_estimate": 0.5,
             "stages": None,
             "args": None,
-            "files": r"^pyproject\.toml$",
+            "files": r"^ pyproject\.toml$",
             "exclude": None,
             "additional_dependencies": None,
             "types_or": None,
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
     ],
     "security": [
@@ -154,6 +179,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "bandit",
@@ -171,6 +197,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
     ],
     "formatting": [
@@ -190,12 +217,13 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "ruff-check",
             "name": None,
             "repo": "https://github.com/astral-sh/ruff-pre-commit",
-            "rev": "v0.12.11",
+            "rev": "v0.12.12",
             "tier": 2,
             "time_estimate": 1.5,
             "stages": None,
@@ -207,12 +235,13 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "ruff-format",
             "name": None,
             "repo": "https://github.com/astral-sh/ruff-pre-commit",
-            "rev": "v0.12.11",
+            "rev": "v0.12.12",
             "tier": 2,
             "time_estimate": 1.0,
             "stages": None,
@@ -224,6 +253,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "mdformat",
@@ -241,25 +271,27 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
     ],
     "analysis": [
         {
-            "id": "vulture",
-            "name": None,
-            "repo": "https://github.com/jendrikseipp/vulture",
-            "rev": "v2.14",
+            "id": "skylos",
+            "name": "skylos-dead-code-detection",
+            "repo": "local",
+            "rev": "",
             "tier": 3,
-            "time_estimate": 2.0,
+            "time_estimate": 0.1,
             "stages": ["pre-push", "manual"],
-            "args": None,
-            "files": "^crackerjack/.*\\.py$",
+            "args": ["crackerjack"],
+            "files": None,
             "exclude": None,
             "additional_dependencies": None,
             "types_or": None,
-            "language": None,
-            "entry": None,
+            "language": "system",
+            "entry": "skylos",
             "experimental": False,
+            "pass_filenames": False,
         },
         {
             "id": "creosote",
@@ -277,6 +309,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "complexipy",
@@ -284,9 +317,9 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "repo": "https://github.com/rohaquinlop/complexipy-pre-commit",
             "rev": "v3.3.0",
             "tier": 3,
-            "time_estimate": 2.0,
+            "time_estimate": 1.0,
             "stages": ["pre-push", "manual"],
-            "args": ["-d", "low"],
+            "args": ["-d", "low", "--max-complexity-allowed", "15"],
             "files": r"^crackerjack/.*\.py$",
             "exclude": r"^(\.venv/|tests/)",
             "additional_dependencies": None,
@@ -294,6 +327,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
         },
         {
             "id": "refurb",
@@ -311,61 +345,46 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "language": None,
             "entry": None,
             "experimental": False,
+            "pass_filenames": None,
+        },
+        {
+            "id": "zuban",
+            "name": "zuban-type-checking",
+            "repo": "local",
+            "rev": "",
+            "tier": 3,
+            "time_estimate": 0.15,
+            "stages": ["pre-push", "manual"],
+            "args": ["--config-file", "mypy.ini", "./crackerjack"],
+            "files": None,
+            "exclude": None,
+            "additional_dependencies": None,
+            "types_or": None,
+            "language": "system",
+            "entry": "uv run zuban check",
+            "experimental": False,
+            "pass_filenames": False,
         },
         {
             "id": "pyright",
-            "name": None,
-            "repo": "https://github.com/RobertCraigie/pyright-python",
-            "rev": "v1.1.404",
+            "name": "pyright-type-checking",
+            "repo": "local",
+            "rev": "",
             "tier": 3,
-            "time_estimate": 5.0,
+            "time_estimate": 0.25,
             "stages": ["pre-push", "manual"],
-            "args": None,
+            "args": [],
             "files": "^crackerjack/.*\\.py$",
             "exclude": r"^crackerjack/(mcp|plugins)/.*\.py$|crackerjack/code_cleaner\.py$",
             "additional_dependencies": None,
             "types_or": None,
-            "language": None,
-            "entry": None,
+            "language": "system",
+            "entry": "uv run pyright",
             "experimental": False,
+            "pass_filenames": None,
         },
     ],
-    "experimental": [
-        {
-            "id": "pyrefly",
-            "name": "pyrefly",
-            "repo": "local",
-            "rev": "",
-            "tier": 3,
-            "time_estimate": 5.0,
-            "stages": ["manual"],
-            "args": ["--check"],
-            "files": "^crackerjack/.*\\.py$",
-            "exclude": None,
-            "additional_dependencies": ["pyrefly >= 0.1.0"],
-            "types_or": ["python"],
-            "language": "python",
-            "entry": "python -m pyrefly",
-            "experimental": True,
-        },
-        {
-            "id": "ty",
-            "name": "ty",
-            "repo": "local",
-            "rev": "",
-            "tier": 3,
-            "time_estimate": 2.0,
-            "stages": ["manual"],
-            "args": ["--check"],
-            "files": "^crackerjack/.*\\.py$",
-            "exclude": None,
-            "additional_dependencies": ["ty >= 0.1.0"],
-            "types_or": ["python"],
-            "language": "python",
-            "entry": "python -m ty",
-            "experimental": True,
-        },
-    ],
+    "experimental": [],
 }
 
 CONFIG_MODES: dict[str, ConfigMode] = {
@@ -392,7 +411,7 @@ CONFIG_MODES: dict[str, ConfigMode] = {
 PRE_COMMIT_TEMPLATE = """repos:
 {%- for repo in repos %}
   {%- if repo.comment %}
-  # {{ repo.comment }}
+
   {%- endif %}
   - repo: {{ repo.repo }}
     {%- if repo.rev %}
@@ -413,6 +432,9 @@ PRE_COMMIT_TEMPLATE = """repos:
         {%- if hook.args %}
         args: {{ hook.args | tojson }}
         {%- endif %}
+        {%- if hook.pass_filenames is not none %}
+        pass_filenames: {{ hook.pass_filenames | lower }}
+        {%- endif %}
         {%- if hook.files %}
         files: {{ hook.files }}
         {%- endif %}
@@ -430,7 +452,7 @@ PRE_COMMIT_TEMPLATE = """repos:
         {%- endif %}
     {%- endfor %}
 
-{%- endfor %}
+{%-endfor %}
 """
 
 
@@ -563,7 +585,7 @@ def generate_config_for_mode(
 
 
 def get_available_modes() -> list[str]:
-    return list(CONFIG_MODES.keys())
+    return list[t.Any](CONFIG_MODES.keys())
 
 
 def add_experimental_hook(hook_id: str, hook_config: HookMetadata) -> None:
