@@ -1,4 +1,5 @@
 import time
+import typing as t
 from collections import deque
 from datetime import datetime
 from pathlib import Path
@@ -63,7 +64,7 @@ class MetricCard(Static):
     }
     """
 
-    value = reactive(" -- ")
+    value = reactive(" --")
     label = reactive("Metric")
     trend = reactive("")
     status = reactive("")
@@ -71,10 +72,10 @@ class MetricCard(Static):
     def __init__(
         self,
         label: str,
-        value: str = " -- ",
+        value: str = " --",
         trend: str = "",
         status: str = "",
-        **kwargs,
+        **kwargs: t.Any,
     ) -> None:
         super().__init__(**kwargs)
         self.label = label
@@ -205,7 +206,7 @@ class PerformanceWidget(Static):
     }
     """
 
-    def __init__(self, **kwargs) -> None:
+    def __init__(self, **kwargs: t.Any) -> None:
         super().__init__(**kwargs)
         self.cpu_history: deque[float] = deque(maxlen=50)
         self.memory_history: deque[float] = deque(maxlen=50)
@@ -307,7 +308,7 @@ class CrackerjackDashboard(App):
     }
     """
 
-    def __init__(self, **kwargs) -> None:
+    def __init__(self, **kwargs: t.Any) -> None:
         super().__init__(**kwargs)
 
         self.job_collector = JobDataCollector()
@@ -414,7 +415,7 @@ class CrackerjackDashboard(App):
         try:
             timeout = aiohttp.ClientTimeout(total=5.0)
             async with aiohttp.ClientSession(timeout=timeout) as session:
-                async with session.get("http://localhost:8675/") as response:
+                async with session.get("http: / / localhost: 8675 /") as response:
                     return response.status == 200
         except Exception:
             return False
@@ -425,7 +426,7 @@ class CrackerjackDashboard(App):
 
             cpu_percent = psutil.cpu_percent(interval=None)
             memory = psutil.virtual_memory()
-            memory_mb = memory.used // (1024 * 1024)
+            memory_mb = memory.used / (1024 * 1024)
 
             cpu_metric = self.query_one("#cpu_metric", MetricCard)
             memory_metric = self.query_one("#memory_metric", MetricCard)
@@ -459,9 +460,12 @@ class CrackerjackDashboard(App):
         try:
             timeout = aiohttp.ClientTimeout(total=10.0)
             async with aiohttp.ClientSession(timeout=timeout) as session:
-                async with session.get("http://localhost:8675/api/jobs") as response:
+                async with session.get(
+                    "http: / / localhost: 8675 / api / jobs"
+                ) as response:
                     if response.status == 200:
-                        return await response.json()
+                        json_result = await response.json()
+                        return t.cast(dict[str, t.Any], json_result)
                     return {}
         except Exception as e:
             self.log(f"Error fetching WebSocket jobs: {e}")
@@ -469,24 +473,25 @@ class CrackerjackDashboard(App):
 
     async def _collect_jobs_from_filesystem(self) -> dict[str, Any]:
         try:
-            jobs = {}
+            jobs: dict[str, Any] = {}
 
             import tempfile
 
             temp_dir = Path(tempfile.gettempdir())
-            debug_files = temp_dir.glob("crackerjack-debug-*.log")
+            debug_files = temp_dir.glob("crackerjack - debug-*.log")
             for debug_file in debug_files:
                 try:
                     if debug_file.stat().st_mtime > (time.time() - 3600):
                         debug_file.read_text()
-                        job_id = debug_file.stem.replace("crackerjack-debug-", "")
+                        job_id = debug_file.stem.replace("crackerjack-debug -", "")
                         jobs[job_id] = {
                             "id": job_id,
                             "status": "completed",
                             "log_file": str(debug_file),
                             "timestamp": debug_file.stat().st_mtime,
                         }
-                except Exception:
+                except Exception as e:
+                    self.log(f"Could not process debug file {debug_file}: {e}")
                     continue
 
             return jobs
@@ -512,10 +517,10 @@ class CrackerjackDashboard(App):
                 reverse=True,
             ):
                 status = job_data.get("status", "unknown")
-                stage = job_data.get("current_stage", "N/A")
+                stage = job_data.get("current_stage", "N / A")
                 progress = job_data.get("progress", 0)
                 started = datetime.fromtimestamp(job_data.get("timestamp", 0)).strftime(
-                    "%H:%M:%S",
+                    "% H: % M: % S",
                 )
                 duration = self._format_duration(job_data.get("duration", 0))
                 issues = job_data.get("issues_found", 0)
@@ -577,7 +582,7 @@ class CrackerjackDashboard(App):
         try:
             log_display = self.query_one("#log_display", Log)
 
-            current_time = datetime.now().strftime("%H:%M:%S")
+            current_time = datetime.now().strftime("% H: % M: % S")
             if len(self.logs_buffer) % 10 == 0:
                 log_display.write_line(f"[{current_time}] Dashboard refresh completed")
 
